@@ -195,7 +195,7 @@ class Fido2Server:
             CredentialCreationOptions(
                 PublicKeyCredentialCreationOptions(
                     self.rp,
-                    user,
+                    PublicKeyCredentialUserEntity.from_dict(user),
                     challenge,
                     self.allowed_algorithms,
                     self.timeout,
@@ -442,22 +442,30 @@ class Fido2Server:
         }
 
 
+# TODO 2.0: Delete, or move to an example
 def verify_app_id(app_id: str, origin: str) -> bool:
     """Checks if a FIDO U2F App ID is usable for a given origin.
 
     :param app_id: The App ID to validate.
     :param origin: The origin of the request.
     :return: True if the App ID is usable by the origin, False if not.
+
+    .. deprecated:: 1.2.0
+       This will be removed in python-fido2 2.0.
     """
     url = urlparse(app_id)
-    if url.scheme != "https":
-        return False
     hostname = url.hostname
+    # Note that FIDO U2F requires a secure context, i.e. an origin with https scheme.
+    # However, most browsers also treat http://localhost as a secure context. See
+    # https://groups.google.com/a/chromium.org/g/blink-dev/c/RC9dSw-O3fE/m/E3_0XaT0BAAJ
+    if url.scheme != "https" and (url.scheme, hostname) != ("http", "localhost"):
+        return False
     if not hostname:
         return False
     return verify_rp_id(hostname, origin)
 
 
+# TODO 2.0: Delete, or move to an example
 class U2FFido2Server(Fido2Server):
     """Fido2Server which can be used with existing U2F credentials.
 
@@ -468,7 +476,11 @@ class U2FFido2Server(Fido2Server):
     :param app_id: The appId which was used for U2F registration.
     :param verify_u2f_origin: (optional) Alternative function to validate an
         origin for U2F credentials.
+
     For other parameters, see Fido2Server.
+
+    .. deprecated:: 1.2.0
+       This will be removed in python-fido2 2.0.
     """
 
     def __init__(
